@@ -43,7 +43,7 @@ import time
 import json
 
 
-def run_unit_tests() -> None:
+def run_unit_tests() -> None:  # pragma: no cover
     """Run all unit tests."""
     # Run pytest in another process to ensure that the workspace is and stays
     # clean, and all Matplotlib windows are closed correctly after the tests.
@@ -53,8 +53,7 @@ def run_unit_tests() -> None:
     os.chdir(kineticstoolkit.config.root_folder + '/tests')
     subprocess.call(['coverage', 'run',
                      '--source', '../kineticstoolkit',
-                     '--omit', '../kineticstoolkit/dev.py',
-                     '--omit', '../kineticstoolkit/cmdgui.py',
+                     '--omit', '../kineticstoolkit/external/*',
                      '-m', 'pytest', '--ignore=interactive'],
                     env=kineticstoolkit.config.env)
     subprocess.call(['coverage', 'html'], env=kineticstoolkit.config.env)
@@ -64,22 +63,30 @@ def run_unit_tests() -> None:
     os.chdir(cwd)
 
 
-def run_static_type_checker() -> None:
+def run_style_formatter() -> None:  # pragma: no cover
+    """Run style formatter (autopep8)."""
+    print("Running autopep8...")
+    subprocess.call(['autopep8', '-r', '-i',
+                     kineticstoolkit.config.root_folder],
+                    env=kineticstoolkit.config.env)
+
+
+def run_static_type_checker() -> None:  # pragma: no cover
     """Run static typing checker (mypy)."""
     # Run pytest in another process to ensure that the workspace is and stays
     # clean, and all Matplotlib windows are closed correctly after the tests.
-    print('Running mypy...')
+    print("Running mypy...")
     cwd = os.getcwd()
     os.chdir(kineticstoolkit.config.root_folder)
-    subprocess.call(['mypy', '--ignore-missing-imports', '-p',
-                     'kineticstoolkit'],
+    subprocess.call(['mypy', '--config-file', 'kineticstoolkit/mypy.ini',
+                     '-p', 'kineticstoolkit'],
                     env=kineticstoolkit.config.env)
     os.chdir(cwd)
 
 
-def run_doc_tests() -> None:
+def run_doc_tests() -> None:  # pragma: no cover
     """Run all doc tests."""
-    print('Running doc tests...')
+    print("Running doc tests...")
     cwd = os.getcwd()
     os.chdir(kineticstoolkit.config.root_folder + '/kineticstoolkit')
     for file in os.listdir():
@@ -90,10 +97,11 @@ def run_doc_tests() -> None:
                                 optionflags=doctest.NORMALIZE_WHITESPACE)
                 print(f"Doctests passed in file {file}.")
             except Exception:
-                print(f'Could not run the doctest in file {file}.')
+                print(f"Could not run the doctest in file {file}.")
     os.chdir(cwd)
 
-def _generate_tutorial(file: str) -> None:
+
+def _generate_tutorial(file: str) -> None:  # pragma: no cover
     """Generate one tutorial."""
     print(file)
     subprocess.call(['jupyter-nbconvert', '--execute',
@@ -113,7 +121,7 @@ def _generate_tutorial(file: str) -> None:
         json.dump(contents, fid, indent=1)
 
 
-def build_tutorials() -> None:
+def build_tutorials() -> None:  # pragma: no cover
     """Build the markdown from notebooks tutorials."""
     print('Generating tutorials...')
     now = time.time()
@@ -143,7 +151,7 @@ def build_tutorials() -> None:
     print(f'Done in {time.time() - now} seconds.')
 
 
-def build_website(clean: bool = False) -> None:
+def build_website(clean: bool = False) -> None:  # pragma: no cover
     """
     Build the website using sphinx.
 
@@ -154,16 +162,19 @@ def build_website(clean: bool = False) -> None:
     os.chdir(kineticstoolkit.config.root_folder + '/doc')
 
     if clean:
-        subprocess.call(['make', 'clean'], env=kineticstoolkit.config.env)
+        shutil.rmtree(kineticstoolkit.config.root_folder + '/doc/api',
+                      ignore_errors=True)
+        subprocess.call(['make', 'clean'],
+                        env=kineticstoolkit.config.env)
 
     # Generate API
-    print('Generating API...')
-    os.environ['SPHINX_APIDOC_OPTIONS'] = \
-        'members,undoc-members,autosummary'
-    subprocess.call(['sphinx-apidoc', '-q', '-e', '-f', '-d', '3',
-                      '-o', 'api', '../kineticstoolkit',
-                      'external'],
-                    env=kineticstoolkit.config.env)
+#    print('Generating API...')
+#     os.environ['SPHINX_APIDOC_OPTIONS'] = (
+# #        'members,undoc-members,autosummary'
+#         'members,undoc-members,autosummary')
+#     subprocess.call(['sphinx-apidoc', '-q', '-e', '-f', '-d', '3',
+#                       '-o', 'api', '../kineticstoolkit',
+#                       'external'])
 
     # Generate site
     print('Generating site...')
@@ -171,13 +182,16 @@ def build_website(clean: bool = False) -> None:
 
     # Open site
     webbrowser.open_new_tab(
-        'file://' + kineticstoolkit.config.root_folder + '/doc/_build/html/index.html')
+        'file://' + kineticstoolkit.config.root_folder +
+        '/doc/_build/html/index.html')
     os.chdir(cwd)
 
 
-def clean() -> None:
+def clean() -> None:  # pragma: no cover
     """Remove outputs in jupyter notebooks (before committing to git)."""
-    for (folder, _, files) in os.walk(kineticstoolkit.config.root_folder + '/doc'):
+    for (folder, _, files) in os.walk(
+            kineticstoolkit.config.root_folder + '/doc'):
+
         if any(['.ipynb' in file for file in files]):
             subprocess.call(['jupyter-nbconvert',
                              '--ClearOutputPreprocessor.enabled=True',
@@ -187,7 +201,7 @@ def clean() -> None:
                             env=kineticstoolkit.config.env)
 
 
-def compile_for_pypi() -> None:
+def compile_for_pypi() -> None:  # pragma: no cover
     """Compile for PyPi."""
     shutil.rmtree(kineticstoolkit.config.root_folder + '/dist',
                   ignore_errors=True)
@@ -198,7 +212,7 @@ def compile_for_pypi() -> None:
                     env=kineticstoolkit.config.env)
 
 
-def upload_to_pypi() -> None:
+def upload_to_pypi() -> None:  # pragma: no cover
     """Upload to PyPi. Only works on macOS for now."""
     root_folder = kineticstoolkit.config.root_folder
     subprocess.call([
@@ -209,8 +223,9 @@ def upload_to_pypi() -> None:
         env=kineticstoolkit.config.env)
 
 
-def release() -> None:
-    """Run all functions for release, without packaging and uploading."""
+def build() -> None:  # pragma: no cover
+    """Run all testing and building functions."""
+    run_style_formatter()
     run_doc_tests()
     run_static_type_checker()
     run_unit_tests()
