@@ -27,7 +27,7 @@ __license__ = "Apache 2.0"
 
 import kineticstoolkit.geometry as geometry
 from kineticstoolkit import TimeSeries
-from kineticstoolkit.decorators import stable, unstable, experimental, directory
+from kineticstoolkit.decorators import unstable, directory
 from typing import Sequence, Dict, Any
 
 import numpy as np
@@ -41,7 +41,6 @@ except ModuleNotFoundError:
                   'will not work.')
 
 
-@stable
 def read_c3d_file(filename: str) -> TimeSeries:
     """
     Read markers from a C3D file.
@@ -100,7 +99,7 @@ def read_c3d_file(filename: str) -> TimeSeries:
 
         label_name = labels[i_label]
 
-        output.data[label_name] = (
+        output.data[label_name] = np.array(
             [point_factor, point_factor, point_factor, 1] *
             reader['data']['points'][:, i_label, :].T)
 
@@ -165,7 +164,6 @@ def write_c3d_file(filename: str, markers: TimeSeries) -> None:
     c3d.write(filename)
 
 
-@stable
 def read_n3d_file(filename: str, labels: Sequence[str] = []):
     """
     Read markers from an NDI N3D file.
@@ -223,8 +221,8 @@ def read_n3d_file(filename: str, labels: Sequence[str] = []):
 
         # Transformation to a TimeSeries
         ts = TimeSeries(
-                time=np.linspace(0, n_frames / collection_frame_frequency,
-                                 n_frames))
+            time=np.linspace(0, n_frames / collection_frame_frequency,
+                             n_frames))
 
         for i_marker in range(n_markers):
             if labels != []:
@@ -233,8 +231,8 @@ def read_n3d_file(filename: str, labels: Sequence[str] = []):
                 label = f'Marker{i_marker}'
 
             ts.data[label] = np.block([[
-                    ndi_array[:, 3*i_marker:3*i_marker+3],
-                    np.ones((n_frames, 1))]])
+                ndi_array[:, 3*i_marker:3*i_marker+3],
+                np.ones((n_frames, 1))]])
             ts.add_data_info(label, 'Unit', 'm')
 
     return ts
@@ -353,7 +351,6 @@ def read_n3d_file(filename: str, labels: Sequence[str] = []):
 #            return(the_timeseries)
 
 
-@experimental
 def create_rigid_body_config(
     markers: TimeSeries,
     marker_names: Sequence[str]
@@ -361,6 +358,11 @@ def create_rigid_body_config(
     """
     Create a rigid body configuration based on a static acquisition.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.4, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -386,7 +388,7 @@ def create_rigid_body_config(
 
     for i_marker, marker in enumerate(marker_names):
         global_points[:, :, i_marker] = \
-                markers.data[marker][:, :]
+            markers.data[marker][:, :]
 
     # Remove samples where at least one marker is invisible
     global_points = global_points[~geometry.isnan(global_points)]
@@ -396,30 +398,34 @@ def create_rigid_body_config(
         x=global_points[:, :, 1] - global_points[:, :, 0],
         xy=global_points[:, :, 2] - global_points[:, :, 0])
     local_points = geometry.get_local_coordinates(
-            global_points, rigid_bodies)
+        global_points, rigid_bodies)
 
     # Take the average
-    local_points = np.mean(local_points, axis=0)
+    local_points = np.array(np.mean(local_points, axis=0))
     local_points = local_points[np.newaxis]
 
     return {
-            'LocalPoints' : local_points,
-            'MarkerNames' : marker_names
-            }
+        'LocalPoints': local_points,
+        'MarkerNames': marker_names
+    }
 
 
-@experimental
 def register_markers(
         markers: TimeSeries,
         rigid_body_configs: Dict[str, Dict[str, Any]],
         verbose: bool = False
-        ) -> TimeSeries:
+) -> TimeSeries:
     """
     Calculate the trajectory of rigid bodies.
 
     Calculates the trajectory of rigid bodies using
     `ktk.geometry.register_points`.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.4, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -438,8 +444,8 @@ def register_markers(
         transformations.
     """
     rigid_bodies = TimeSeries(time=markers.time,
-                                  time_info=markers.time_info,
-                                  events=markers.events)
+                              time_info=markers.time_info,
+                              events=markers.events)
 
     for rigid_body_name in rigid_body_configs:
         if verbose is True:
@@ -449,35 +455,39 @@ def register_markers(
         local_points = rigid_body_configs[rigid_body_name]['LocalPoints']
 
         global_points = np.empty(
-                (len(markers.time), 4, local_points.shape[2]))
+            (len(markers.time), 4, local_points.shape[2]))
         for i_marker in range(global_points.shape[2]):
             marker_name = rigid_body_configs[
-                    rigid_body_name]['MarkerNames'][i_marker]
+                rigid_body_name]['MarkerNames'][i_marker]
             if marker_name in markers.data:
                 global_points[:, :, i_marker] = markers.data[marker_name]
             else:
                 global_points[:, :, i_marker] = np.nan
 
-        (local_points, global_points) = geometry.match_size(
-                local_points, global_points)
+        (local_points, global_points) = geometry._match_size(
+            local_points, global_points)
 
         # Compute the rigid body trajectory
         rigid_bodies.data[rigid_body_name] = geometry.register_points(
-                global_points, local_points)
+            global_points, local_points)
 
     return rigid_bodies
 
 
-@experimental
 def create_virtual_marker_config(
         markers: TimeSeries,
         rigid_bodies: TimeSeries,
         marker_name: str,
         rigid_body_name: str
-        ) -> Dict[str, Any]:
+) -> Dict[str, Any]:
     """
     Create a virtual marker configuration based on a probing acquisition.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.4, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -542,7 +552,6 @@ def write_trc_file(markers: TimeSeries, filename: str) -> None:
     camera_rate = data_rate
     units = 'm'
 
-
     # Open file
     with open(filename, 'w') as fid:
         fid.write(f'PathFileType\t4\t(X/Y/Z)\t{filename}\n')
