@@ -30,7 +30,7 @@ __license__ = "Apache 2.0"
 
 from kineticstoolkit.timeseries import TimeSeries
 from kineticstoolkit.timeseries import dataframe_to_dict_of_arrays
-from kineticstoolkit.decorators import stable, private, directory
+from kineticstoolkit.decorators import directory
 import kineticstoolkit.config
 
 import scipy.io as spio
@@ -50,7 +50,6 @@ import zipfile
 from typing import Any, List
 
 
-@stable
 def save(filename: str, variable: Any) -> None:
     """
     Save a variable to a ktk.zip file.
@@ -152,7 +151,8 @@ def save(filename: str, variable: Any) -> None:
     }
 
     # Save
-    temp_folder = kineticstoolkit.config.temp_folder + '/save' + str(time.time())
+    temp_folder = kineticstoolkit.config.temp_folder + \
+        '/save' + str(time.time())
 
     try:
         shutil.rmtree(temp_folder)
@@ -171,7 +171,6 @@ def save(filename: str, variable: Any) -> None:
     shutil.rmtree(temp_folder)
 
 
-@private
 def _load(filename):
     """
     Load the contents of a folder or filename.
@@ -273,7 +272,6 @@ def _load(filename):
         return ('', None)
 
 
-@private
 def _load_object_hook(obj):
     if 'class__' in obj:
         to_class = obj['class__']
@@ -316,7 +314,6 @@ def _load_object_hook(obj):
         return obj
 
 
-@private
 def _load_ktk_zip(filename, include_metadata=False):
     """Read the ktk.zip file format."""
 
@@ -333,7 +330,6 @@ def _load_ktk_zip(filename, include_metadata=False):
         else:
             return data
 
-
     except Exception:
         # No data.json. It seems to be the old format.
 
@@ -372,7 +368,6 @@ def _load_ktk_zip(filename, include_metadata=False):
                 return variable[key]
 
 
-@stable
 def load(filename: str) -> Any:
     """
     Load a ktk.zip file.
@@ -409,7 +404,6 @@ def load(filename: str) -> Any:
         raise ValueError('The file must be either zip or mat.')
 
 
-@private
 def _loadmat(filename):
     """
     Load a Matlab's MAT file.
@@ -444,7 +438,6 @@ def _loadmat(filename):
         return data
 
 
-@private
 def _convert_cell_arrays_to_lists(the_input):
     """
     Convert cell arrays to lists.
@@ -464,7 +457,7 @@ def _convert_cell_arrays_to_lists(the_input):
                 the_list = []
                 for i_cell in range(length):
                     the_list.append(_convert_cell_arrays_to_lists(
-                            the_input[f'cell{i_cell+1}']))
+                        the_input[f'cell{i_cell+1}']))
                 the_input = the_list
 
             except KeyError:
@@ -487,13 +480,13 @@ def _convert_cell_arrays_to_lists(the_input):
 
                 # Create and populate the list
                 the_list = [
-                        [None for i_col in range(n_cols)]
-                        for i_row in range(n_rows)]
+                    [None for i_col in range(n_cols)]
+                    for i_row in range(n_rows)]
                 for cell in the_input.keys():
                     address = extract_address(cell)
                     if address is not None:
                         the_list[int(address[0])-1][int(address[1])-1] = \
-                                _convert_cell_arrays_to_lists(the_input[cell])
+                            _convert_cell_arrays_to_lists(the_input[cell])
 
                 the_input = the_list
 
@@ -507,7 +500,6 @@ def _convert_cell_arrays_to_lists(the_input):
     return the_input
 
 
-@private
 def _convert_to_timeseries(the_input):
     """
     Convert dicts of Matlab timeseries to Kinetics Toolkit TimeSeries.
@@ -589,7 +581,6 @@ def _convert_to_timeseries(the_input):
         return the_input
 
 
-@private
 def _recursive_matstruct_to_dict(variable):
     """Recursively converts Mat-objects in dicts or arrays to nested dicts."""
     if isinstance(variable, spio.matlab.mio5_params.mat_struct):
@@ -604,7 +595,6 @@ def _recursive_matstruct_to_dict(variable):
     return variable
 
 
-@private
 def _todict(variable):
     """Construct dicts from Mat-objects."""
     dict = {}
@@ -619,3 +609,10 @@ module_locals = locals()
 
 def __dir__():
     return directory(module_locals)
+
+
+if __name__ == "__main__":  # pragma: no cover
+    import doctest
+    import kineticstoolkit as ktk
+    import numpy as np
+    doctest.testmod(optionflags=doctest.NORMALIZE_WHITESPACE)
