@@ -29,7 +29,7 @@ __license__ = "Apache 2.0"
 
 
 from kineticstoolkit.timeseries import TimeSeries
-from kineticstoolkit.decorators import stable, experimental, unstable, directory
+from kineticstoolkit.decorators import directory
 
 import matplotlib.pyplot as plt
 import matplotlib as mpl
@@ -38,7 +38,7 @@ import numpy as np
 from numpy import sin, cos
 import time
 import copy
-from typing import *
+from typing import Union, Sequence, Dict, Any, Optional
 
 # To fit the new viewpoint on selecting a new marker
 import scipy.optimize as optim
@@ -141,11 +141,21 @@ class Player:
                         self.markers.data_info[key] = one_ts.data_info[key]
 
                 elif one_ts.data[key].shape[1:] == (4, 4):
+
+                    # Add the frames
                     self.rigid_bodies.data[key] = one_ts.data[key]
                     if key in one_ts.data_info:
                         self.rigid_bodies.data_info[key] = \
                             one_ts.data_info[key]
 
+                    # Add the frame origins as "markers"
+                    key_label = f'[{key}] origin'
+                    self.markers.data[key_label] = one_ts.data[key][:, :, 3]
+                    if key in one_ts.data_info:
+                        self.markers.data_info[key_label] = (
+                            one_ts.data_info[key]
+                        )
+
                 else:
                     raise ValueError('TimeSeries data must be of shape Nx4 '
                                      '(markers) or Nx4x4 (rigid bodies)')
@@ -546,9 +556,12 @@ class Player:
                 rbz_data[:, 0], rbz_data[:, 1])
 
         # Update the window title
-        self.objects['Figure'].canvas.set_window_title(
-            f'Frame {self.current_frame}, ' +
-            '%2.2f s.' % self.time[self.current_frame])
+        try:
+            self.objects['Figure'].canvas.manager.set_window_title(
+                f'Frame {self.current_frame}, ' +
+                '%2.2f s.' % self.time[self.current_frame])
+        except AttributeError:
+            pass
 
         self.objects['Figure'].canvas.draw()
 
@@ -613,7 +626,7 @@ class Player:
 
     def _set_time(self, time: float) -> None:
         """Set current frame to a given time and update plots."""
-        index = np.argmin(np.abs(self.time - time))
+        index = int(np.argmin(np.abs(self.time - time)))
         self._set_frame(index)
 
     def _select_none(self) -> None:
@@ -627,7 +640,6 @@ class Player:
                 except KeyError:
                     self.markers.add_data_info(marker, 'Color', 'w')
 
-    @stable
     def close(self) -> None:
         """Close the Player and its associated window."""
         plt.close(self.objects['Figure'])
@@ -677,7 +689,7 @@ class Player:
             self._set_new_target(
                 self.markers.data[selected_marker][self.current_frame])
             marker_position = self.markers.data[selected_marker][
-            self.current_frame]
+                self.current_frame]
 
             self._update_plots()
 
@@ -812,12 +824,11 @@ class Player:
                 (event.y - self.state['MousePositionOnPress'][1]) / 250
             self._update_plots()
 
-    @experimental
     def to_html5(self,
-                  start_frame: Optional[int] = None,
-                  stop_frame: Optional[int] = None,
-                  start_time: Optional[int] = None,
-                  stop_time: Optional[int] = None):
+                 start_frame: Optional[int] = None,
+                 stop_frame: Optional[int] = None,
+                 start_time: Optional[int] = None,
+                 stop_time: Optional[int] = None):
         """
         Create an html5 video for displaying in Jupyter notebooks.
 
@@ -842,11 +853,10 @@ class Player:
         -------
         A matplotlib animation object for displaying as html5.
 
-        Use
-        ------
-        Instanciate the player, then call this method on it:
-
-            ktk.Player(markers, [...]).to_notebook()
+        Warnings
+        --------
+        This function, which has been introduced in 0.4, is still experimental
+        and may change signature or behaviour in the future.
 
         """
         mpl.rcParams['animation.html'] = 'html5'
@@ -855,13 +865,13 @@ class Player:
             if start_time is None:
                 start_frame = 0
             else:
-                start_frame = np.argmin(np.abs(self.time - start_time))
+                start_frame = int(np.argmin(np.abs(self.time - start_time)))
 
         if stop_frame is None:
             if stop_time is None:
                 stop_frame = -1
             else:
-                stop_frame = np.argmin(np.abs(self.time - stop_time))
+                stop_frame = int(np.argmin(np.abs(self.time - stop_time)))
 
         if stop_frame < 0:
             stop_frame = self.n_frames + stop_frame + 1
