@@ -28,7 +28,7 @@ __license__ = "Apache 2.0"
 import kineticstoolkit.filters as filters
 import kineticstoolkit.cycles as cycles
 from kineticstoolkit import TimeSeries
-from kineticstoolkit.decorators import stable, unstable, private, dead, directory
+from kineticstoolkit.decorators import unstable, dead, directory
 
 import numpy as np
 from numpy import sin, cos, pi
@@ -38,7 +38,6 @@ import struct  # to unpack binary data from SmartWheels' txt files
 from typing import Union, Optional, List
 
 
-@stable
 def read_file(filename: str, /, file_format: str = '') -> TimeSeries:
     """
     Read a file containing pushrim kinetics data.
@@ -149,7 +148,7 @@ def read_file(filename: str, /, file_format: str = '') -> TimeSeries:
         angle = angle_ticks / 4096 * 2 * np.pi
 
         ts = TimeSeries(
-            time=np.linspace(0, (length - 1) / 240, length))
+            time=np.linspace(0, (length - 1) / 240, length - 1))
         ts.data['Channels'] = np.concatenate(
             [ch1[:, np.newaxis],
              ch2[:, np.newaxis],
@@ -212,7 +211,7 @@ def find_recovery_indices(Mz: np.ndarray, /) -> np.ndarray:
 
         # Remove the 1% upper.
         index_to_remove = index_to_remove[
-                int(0.99*len(index_to_remove))-1:]
+            int(0.99*len(index_to_remove))-1:]
 
         # Assign nan to these data
         Mz[index_to_remove] = np.nan
@@ -222,11 +221,10 @@ def find_recovery_indices(Mz: np.ndarray, /) -> np.ndarray:
     return index
 
 
-@stable
 def remove_offsets(
         kinetics: TimeSeries,
         baseline_kinetics: Optional[TimeSeries] = None
-        ) -> TimeSeries:
+) -> TimeSeries:
     """
     Remove dynamic offsets in forces and moments.
 
@@ -274,10 +272,10 @@ def remove_offsets(
     # Do the regression
     theta_baseline = theta_baseline[:, np.newaxis]
     q = np.hstack((
-            np.sin(theta_baseline),
-            np.cos(theta_baseline),
-            np.ones((len(theta_baseline), 1))
-            ))
+        np.sin(theta_baseline),
+        np.cos(theta_baseline),
+        np.ones((len(theta_baseline), 1))
+    ))
     A = np.linalg.lstsq(q, f_ofs, rcond=None)
     A = A[0]
 
@@ -289,10 +287,10 @@ def remove_offsets(
                    kinetics.data['Moments'][:, 0:3]))
 
     q = np.hstack((
-            np.sin(theta),
-            np.cos(theta),
-            np.ones((len(theta), 1))
-            ))
+        np.sin(theta),
+        np.cos(theta),
+        np.ones((len(theta), 1))
+    ))
 
     f = f - q @ A
 
@@ -303,7 +301,6 @@ def remove_offsets(
     return kinetics
 
 
-@stable
 def calculate_forces_and_moments(
         kinetics: TimeSeries, /,
         gains: Union[np.ndarray, str],
@@ -370,7 +367,7 @@ def calculate_forces_and_moments(
 
         # Calculate the rotation angle to apply to the calculated kinetics
         if reference_frame == 'wheel':
-            theta = 0
+            theta = np.array([0.0])
         elif reference_frame == 'hub':
             theta = kinetics.data['Angle']
         else:
@@ -414,7 +411,7 @@ def calculate_forces_and_moments(
 
         # Calculate the rotation angle to apply to the calculated kinetics
         if reference_frame == 'wheel':
-            theta = 0
+            theta = np.array([0.0])
         elif reference_frame == 'hub':
             raise NotImplementedError("hub reference_frame not implemented yet"
                                       "for force_cell transducers.")
@@ -445,7 +442,6 @@ def calculate_forces_and_moments(
     return(kinetics)
 
 
-@stable
 def calculate_velocity(tsin: TimeSeries, /) -> TimeSeries:
     """
     Calculate velocity based on wheel angle.
@@ -465,7 +461,7 @@ def calculate_velocity(tsin: TimeSeries, /) -> TimeSeries:
     Returns
     -------
     TimeSeries
-        	A copy of the TimeSeries with the added data key 'Velocity'.
+                A copy of the TimeSeries with the added data key 'Velocity'.
 
     See Also
     --------
@@ -478,15 +474,17 @@ def calculate_velocity(tsin: TimeSeries, /) -> TimeSeries:
     tsangle.time = tsin.time
     tsangle.data['Angle'] = tsin.data['Angle']
     tsvelocity = filters.savgol(tsangle, window_length=21,
-                                    poly_order=2, deriv=1)
+                                poly_order=2, deriv=1)
     tsout = tsin.copy()
     tsout.data['Velocity'] = tsvelocity.data['Angle']
-    tsout.add_data_info('Velocity', 'Unit',
-                        tsout.data_info['Angle']['Unit'] + '/s')
+    try:
+        tsout.add_data_info('Velocity', 'Unit',
+                            tsout.data_info['Angle']['Unit'] + '/s')
+    except KeyError:
+        pass
     return tsout
 
 
-@stable
 def calculate_power(tsin: TimeSeries, /) -> TimeSeries:
     """
     Calculate power based on wheel velocity and moment.
@@ -505,13 +503,12 @@ def calculate_power(tsin: TimeSeries, /) -> TimeSeries:
     """
     tsout = tsin.copy()
     tsout.data['Power'] = (tsout.data['Velocity'] *
-              tsout.data['Moments'][:,2])
+                           tsout.data['Moments'][:, 2])
     tsout.add_data_info('Power', 'Unit', 'W')
     return tsout
 
 
 #--- Deprecated functions ---#
-@private
 def _old_calculate_forces_and_moments(
         kinetics: TimeSeries, calibration_id: str, /) -> TimeSeries:
     """
@@ -543,8 +540,8 @@ def _old_calculate_forces_and_moments(
     Returns
     -------
     TimeSeries
-		A copy of the input TimeSeries, with the added 'Forces'
-		and 'Moments' data keys.
+                A copy of the input TimeSeries, with the added 'Forces'
+                and 'Moments' data keys.
 
     """
 
@@ -623,8 +620,8 @@ def _old_calculate_forces_and_moments(
     else:
         raise ValueError('This calibration ID is not available.')
 
-    gains = np.array(gains)
-    offsets = np.array(offsets)
+    gains_ = np.array(gains)
+    offsets_ = np.array(offsets)
 
     # Calculate the forces and moments and add to the output
     if forcecell == 'smartwheel':
@@ -634,29 +631,29 @@ def _old_calculate_forces_and_moments(
         theta = kinetics.data['Angle']
 
         # Calculate the forces and moments
-        Fx = gains[0] * (
+        Fx = gains_[0] * (
             ch[:, 0] * sin(theta) +
             ch[:, 2] * sin(theta + 2 * pi / 3) +
             ch[:, 4] * sin(theta + 4 * pi / 3)) + offsets[0]
 
-        Fy = gains[1] * (
+        Fy = gains_[1] * (
             ch[:, 0] * cos(theta) +
             ch[:, 2] * cos(theta + 2 * pi / 3) +
             ch[:, 4] * cos(theta + 4 * pi / 3)) + offsets[1]
 
-        Fz = gains[2] * (ch[:, 1] + ch[:, 3] + ch[:, 5]) + offsets[2]
+        Fz = gains_[2] * (ch[:, 1] + ch[:, 3] + ch[:, 5]) + offsets[2]
 
-        Mx = gains[3] * (
+        Mx = gains_[3] * (
             ch[:, 1] * sin(theta) +
             ch[:, 3] * sin(theta + 2 * pi / 3) +
             ch[:, 5] * sin(theta + 4 * pi / 3)) + offsets[3]
 
-        My = gains[4] * (
+        My = gains_[4] * (
             ch[:, 1] * cos(theta) +
             ch[:, 3] * cos(theta + 2 * pi / 3) +
             ch[:, 5] * cos(theta + 4 * pi / 3)) + offsets[4]
 
-        Mz = gains[5] * (ch[:, 0] + ch[:, 2] + ch[:, 4]) + offsets[5]
+        Mz = gains_[5] * (ch[:, 0] + ch[:, 2] + ch[:, 4]) + offsets[5]
         forces_moments = np.block([Fx[:, np.newaxis],
                                    Fy[:, np.newaxis],
                                    Fz[:, np.newaxis],
@@ -666,7 +663,7 @@ def _old_calculate_forces_and_moments(
 
     elif forcecell == 'forcecell':
 
-        forces_moments = gains * kinetics.data['Channels'] + offsets
+        forces_moments = gains_ * kinetics.data['Channels'] + offsets_
 
     elif forcecell == 'matrix':
 
@@ -674,9 +671,9 @@ def _old_calculate_forces_and_moments(
 
         forces_moments = np.empty((n_frames, 6))
         for i_frame in range(n_frames):
-            forces_moments[i_frame] = (gains @
+            forces_moments[i_frame] = (gains_ @
                                        kinetics.data['Channels'][i_frame] +
-                                       offsets)
+                                       offsets_)
 
     # Format these data in the output timeseries
     kinetics = kinetics.copy()
@@ -694,7 +691,9 @@ def _old_calculate_forces_and_moments(
     return(kinetics)
 
 
-@dead
+@dead(since="October 2020",
+      until="December 2021",
+      details="Please use ktk.cycles.detect_cycles instead.")
 def detect_pushes(
         tsin: TimeSeries, /, *,
         push_threshold: float = 5.0,
@@ -704,8 +703,6 @@ def detect_pushes(
     """
     Detect pushes and recoveries automatically.
 
-    Deprecated since October 2020. Please use ktk.cycles.detect_cycles instead.
-
     Parameters
     ----------
     tsin
@@ -748,7 +745,7 @@ def detect_pushes(
 
     # Remove the median if it existed
     ts_force.data['Ftot'] = \
-            ts_force.data['Ftot'] - np.median(ts_force.data['Ftot'])
+        ts_force.data['Ftot'] - np.median(ts_force.data['Ftot'])
 
     # Find the pushes
     ts_force = cycles.detect_cycles(
@@ -767,15 +764,13 @@ def detect_pushes(
     return tsout
 
 
-@dead
+@dead(since="October 2020",
+      until="December 2021",
+      details="Please use ktk.pushrimkinetics.remove_offsets instead.")
 def remove_sinusoids(
         kinetics: TimeSeries,
-        baseline_kinetics: Optional[TimeSeries] = None
-        ) -> TimeSeries:
-    """
-    Deprecated since October 2020. Please use
-    ktk.pushrimkinetics.remove_offsets instead.
-    """
+        baseline_kinetics: Optional[TimeSeries] = None) -> TimeSeries:
+    """Remove offsets."""
     return remove_offsets(kinetics, baseline_kinetics)
 
 
@@ -785,52 +780,52 @@ CALIBRATION_MATRICES['SmartWheel_93'] = {
     'gains': np.array([-0.1080, 0.1080, 0.0930, 0.0222, -0.0222, 0.0234999]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_94'] = {
     'gains': np.array([-0.1070, 0.1070, 0.0960, 0.0222, -0.0222, 0.0230]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_123'] = {
     'gains': np.array([-0.106, 0.106, 0.094, 0.022, -0.022, 0.0234999]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_124'] = {
     'gains': np.array([-0.106, 0.106, 0.0949999, 0.0215, -0.0215, 0.0225]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_125'] = {
     'gains': np.array([-0.104, 0.104, 0.0979999, 0.0215, -0.0215, 0.0225]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_126'] = {
     'gains': np.array([-0.1059999, 0.1059999, 0.086, 0.021, -0.021, 0.023]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_126_S18'] = {
     'gains': np.array([-0.1083, 0.1109, 0.0898, 0.0211, -0.0194, 0.0214]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_179_S18'] = {
     'gains': np.array([-0.1399, 0.1091, 0.0892, 0.0240, -0.0222, 0.0241]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_180_S18'] = {
     'gains': np.array([-0.1069, 0.1091, 0.0932, 0.0240, -0.0226, 0.0238]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['SmartWheel_181_S18'] = {
     'gains': np.array([-0.1152, 0.1095, 0.0791, 0.0229, -0.0197, 0.0220]),
     'offsets': np.array([0.0, 10.0, 0.0, 0.0, 0.0, 0.0]),
     'transducer': 'smartwheel',
-    }
+}
 CALIBRATION_MATRICES['MSA_Racing_1'] = {
     'gains': (np.array([
         [201.027, 1.387, 2.077, -3.852, -1.837, -1.519],
@@ -841,10 +836,10 @@ CALIBRATION_MATRICES['MSA_Racing_1'] = {
         [0.016, -0.015, 0.046, -0.099, -0.076, 25.206]])  # Cell calibration
         / (2.**15) / 10  # ADC gains
         / np.array([-2., -2., -2., -2., -4., -4.])  # Board gains
-        ),
+    ),
     'offsets': [-111.3874, -63.3298, -8.6596, 1.8089, 1.5761, -0.8869],
     'transducer': 'force_cell',
-    }
+}
 
 
 module_locals = locals()
